@@ -195,7 +195,7 @@ def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,
 
 ## -- avn network -- ## 
 def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = False,save_add ="network_avnn.html",height='600px', width='100%',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
-    """ all_edges1: weighted edges 
+    """ all_edges1: weighted edges list
         core_k: if node degree is less than k then edge droped
         cdn=['remote','local'] more in pyvis 
         plot_graph = False for google colab 
