@@ -80,6 +80,9 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
     text, _= emo(text)
     emojis1 =[]
   
+  if text.isupper():
+    text = text.lower()
+  
   ## --- check spelling ---##
   if check_spell:
     spell = Speller('en')
@@ -515,7 +518,8 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     text, emojis1 = emo(text)
     emojis2 =[]
 
-
+  if text.isupper():
+    text = text.lower()
   ## --- check spelling ---##
   
     ## --- check spelling ---##
